@@ -21,6 +21,7 @@ from ...utils.env_keys import REPORT_ERROR_KEY
 from ...utils.exceptions import InvalidJUnitXMLException
 from ...utils.http_client import LaunchableClient
 from ...utils.logger import Logger
+from ...utils.no_build import NO_BUILD_BUILD_NAME, NO_BUILD_TEST_SESSION_ID
 from ...utils.session import parse_session, read_build
 from ..helper import find_or_create_session
 from .case_event import CaseEvent, CaseEventType
@@ -128,6 +129,13 @@ def _validate_group(ctx, param, value):
     default=[],
     cls=KeyValueType,
 )
+@click.option(
+    '--no-build',
+    'is_no_build',
+    help="If you want to only send test reports, please use this option",
+    is_flag=True,
+    hidden=True,
+)
 @click.pass_context
 def tests(
     context: click.core.Context,
@@ -142,6 +150,7 @@ def tests(
     group: str,
     is_allow_test_before_build: bool,
     links: List[str] = [],
+    is_no_build: bool = False,
 ):
     logger = Logger()
 
@@ -153,18 +162,26 @@ def tests(
 
     file_path_normalizer = FilePathNormalizer(base_path, no_base_path_inference=no_base_path_inference)
 
+    if is_no_build and (read_build() and read_build() != ""):
+        raise click.UsageError(
+            'The cli already created `.launchable` file. If you want to use `--no-build` option, please remove `.launchable` file before executing.')  # noqa: E501
+
     try:
-        if subsetting_id:
+        if is_no_build:
+            session_id = "builds/{}/test_sessions/{}".format(NO_BUILD_BUILD_NAME, NO_BUILD_TEST_SESSION_ID)
+            record_start_at = INVALID_TIMESTAMP
+        elif subsetting_id:
             result = get_session_and_record_start_at_from_subsetting_id(subsetting_id, client)
             session_id = result["session"]
             record_start_at = result["start_at"]
         else:
-            session_id = find_or_create_session(
+            # The session_id must be back, so cast to str
+            session_id = str(find_or_create_session(
                 context=context,
                 session=session,
                 build_name=build_name,
                 flavor=flavor,
-                links=links)
+                links=links))
             build_name = read_build()
             record_start_at = get_record_start_at(session_id, client)
 
@@ -208,6 +225,40 @@ def tests(
         def parse_func(self, f: ParseFunc):
             self._parse_func = f
 
+        @property
+        def build_name(self) -> str:
+            return self._build_name
+
+        @build_name.setter
+        def build_name(self, build_name: str):
+            self._build_name = build_name
+
+        @property
+        def test_session_id(self) -> int:
+            return self._test_session_id
+
+        @test_session_id.setter
+        def test_session_id(self, test_session_id: int):
+            self._test_session_id = test_session_id
+
+        # session is generated by `launchable record session` command
+        # the session format is `builds/<BUILD_NUMBER>/test_sessions/<TEST_SESSION_ID>`
+        @property
+        def session(self) -> str:
+            return self._session
+
+        @session.setter
+        def session(self, session: str):
+            self._session = session
+
+        @property
+        def is_no_build(self) -> bool:
+            return self._is_no_build
+
+        @is_no_build.setter
+        def is_no_build(self, is_no_build: bool):
+            self._is_no_build = is_no_build
+
         # setter only property that sits on top of the parse_func property
         def set_junitxml_parse_func(self, f: JUnitXmlParseFunc):
             """
@@ -267,6 +318,10 @@ def tests(
             self.dry_run = dry_run
             self.no_base_path_inference = no_base_path_inference
             self.is_allow_test_before_build = is_allow_test_before_build
+            self.build_name = build_name
+            self.test_session_id = test_session_id
+            self.session = session_id
+            self.is_no_build = is_no_build
 
         def make_file_path_component(self, filepath) -> TestPathComponent:
             """Create a single TestPathComponent from the given file path"""
@@ -278,7 +333,8 @@ def tests(
             ctime = datetime.datetime.fromtimestamp(
                 os.path.getctime(junit_report_file))
 
-            if not self.is_allow_test_before_build and (self.check_timestamp and ctime.timestamp() < record_start_at.timestamp()):
+            if not self.is_allow_test_before_build and not self.is_no_build and (
+                    self.check_timestamp and ctime.timestamp() < record_start_at.timestamp()):
                 format = "%Y-%m-%d %H:%M:%S"
                 logger.warning("skip: {} is too old to report. start_record_at: {} file_created_at: {}".format(
                     junit_report_file, record_start_at.strftime(format), ctime.strftime(format)))
@@ -305,7 +361,12 @@ def tests(
                 exceptions = []
                 for report in reports:
                     try:
-                        yield from self.parse_func(report)
+                        for tc in self.parse_func(report):
+                            # trim empty test path
+                            if len(tc.get('testPath', [])) == 0:
+                                continue
+
+                            yield tc
 
                     except Exception as e:
                         exceptions.append(Exception("Failed to process a report file: {}".format(report), e))
@@ -317,7 +378,7 @@ def tests(
 
             # generator that creates the payload incrementally
             def payload(cases: Generator[TestCase, None, None],
-                        test_runner, group: str) -> Tuple[Dict[str, Union[str, List]], List[Exception]]:
+                        test_runner, group: str) -> Tuple[Dict[str, Union[str, List, bool]], List[Exception]]:
                 nonlocal count
                 cs = []
                 exs = []
@@ -331,11 +392,11 @@ def tests(
                         exs.append(ex)
 
                 count += len(cs)
-                return {"events": cs, "testRunner": test_runner, "group": group}, exs
+                return {"events": cs, "testRunner": test_runner, "group": group, "noBuild": self.is_no_build}, exs
 
             def send(payload: Dict[str, Union[str, List]]) -> None:
                 res = client.request(
-                    "post", "{}/events".format(session_id), payload=payload, compress=True)
+                    "post", "{}/events".format(self.session), payload=payload, compress=True)
 
                 if res.status_code == HTTPStatus.NOT_FOUND:
                     if session:
@@ -362,6 +423,13 @@ def tests(
 
                 res.raise_for_status()
 
+                # If don’t override build, test session and session_id, build and test session will be made per chunk request.
+                if is_no_build:
+                    self.build_name = res.json().get("build", {}).get("build", NO_BUILD_BUILD_NAME)
+                    self.test_session_id = res.json().get("testSession", {}).get("id", NO_BUILD_TEST_SESSION_ID)
+                    self.session = "builds/{}/test_sessions/{}".format(self.build_name, self.test_session_id)
+                    self.is_no_build = False
+
             def recorded_result() -> Tuple[int, int, int, float]:
                 test_count = 0
                 success_count = 0
@@ -395,7 +463,7 @@ def tests(
                     send(p)
                     exceptions.extend(es)
 
-                res = client.request("patch", "{}/close".format(session_id),
+                res = client.request("patch", "{}/close".format(self.session),
                                      payload={"metadata": get_env_values(client)})
                 res.raise_for_status()
                 is_observation = res.json().get("isObservation", False)
@@ -430,8 +498,8 @@ def tests(
 
             click.echo(
                 "Launchable recorded tests for build {} (test session {}) to workspace {}/{} from {} files:".format(
-                    build_name,
-                    test_session_id,
+                    self.build_name,
+                    self.test_session_id,
                     org,
                     workspace,
                     file_count,
@@ -454,7 +522,7 @@ def tests(
                 .format(
                     organization=org,
                     workspace=workspace,
-                    test_session_id=test_session_id,
+                    test_session_id=self.test_session_id,
                 ))
 
     context.obj = RecordTests(dry_run=context.obj.dry_run)
