@@ -11,7 +11,7 @@ from ..testpath import parse_test_path, unparse_test_path
 from . import launchable
 
 
-@click.argument('test_path_file', required=True, type=click.File('r'))
+@click.argument('test_path_file', required=False, type=click.File('r'))
 @launchable.subset
 def subset(client, test_path_file):
     """Subset tests
@@ -20,15 +20,25 @@ def subset(client, test_path_file):
     "file=a.py#class=classA") one per line. Lines start with a hash ('#') are
     considered as a comment and ignored.
     """
-    tps = [s.strip() for s in test_path_file.readlines()]
-    for tp_str in tps:
-        if not tp_str or tp_str.startswith('#'):
-            continue
-        try:
-            tp = parse_test_path(tp_str)
-        except ValueError as e:
-            sys.exit(e.args[0])
-        client.test_path(tp)
+
+    if not client.is_get_tests_from_previous_sessions and test_path_file is None:
+        raise click.BadArgumentUsage("Missing argument 'TEST_PATH_FILE'.")
+
+    if client.is_output_exclusion_rules:
+        raise click.BadArgumentUsage(
+            "Don't need to use `--output-exclusion-rules` option. Please use `--rest` option and use it for exclusion"
+        )
+
+    if not client.is_get_tests_from_previous_sessions:
+        tps = [s.strip() for s in test_path_file.readlines()]
+        for tp_str in tps:
+            if not tp_str or tp_str.startswith('#'):
+                continue
+            try:
+                tp = parse_test_path(tp_str)
+            except ValueError as e:
+                sys.exit(e.args[0])
+            client.test_path(tp)
 
     client.formatter = unparse_test_path
     client.separator = '\n'
@@ -43,8 +53,8 @@ split_subset = launchable.CommonSplitSubsetImpls(__name__, formatter=unparse_tes
 def record_tests(client, test_result_file):
     """Record test results
 
-    TEST_RESULT_FILE is a file that contains a JSON document that describes the
-    test results.
+    TEST_RESULT_FILE is a file that contains a JSON document or JUnit XML file
+    that describes the test results.
 
     ## Example JSON document
 
@@ -111,8 +121,14 @@ def record_tests(client, test_result_file):
       },
       "required": ["testCases"]
     }
+
+    ## JUnit XML TestPath mapping
+
+    If the file path ends with '.xml', the command parses the file as a JUnit XML file. When this mode is used the subset input
+    TestPath should look like 'class={classname}#testcase={testcase}'.
     """
-    def parse(test_result_file: str) -> Generator[CaseEventType, None, None]:
+
+    def parse_json(test_result_file: str) -> Generator[CaseEventType, None, None]:
         with open(test_result_file, 'r') as f:
             doc = json.load(f)
         default_created_at = datetime.datetime.now(datetime.timezone.utc).isoformat()
@@ -134,6 +150,8 @@ def record_tests(client, test_result_file):
                 test_path, duration_secs, CaseEvent.STATUS_MAP[status],
                 case['stdout'], case['stderr'], created_at)
 
+    if not test_result_file.endswith('.xml'):
+        client.parse_func = parse_json
+
     client.report(test_result_file)
-    client.parse_func = parse
     client.run()
