@@ -5,30 +5,17 @@ import sys
 import tempfile
 import unittest
 
-from launchable.testpath import (FilePathNormalizer,
-                                 parse_test_path, unparse_test_path)
+from launchable.testpath import FilePathNormalizer, parse_test_path, unparse_test_path
 
 
 class TestPathEncodingTest(unittest.TestCase):
     def test_parse(self):
-        self.assertEqual(
-            parse_test_path('a=b#c=d'),
-            [{'type': 'a', 'name': 'b'}, {'type': 'c', 'name': 'd'}])
-        self.assertEqual(
-            parse_test_path('&name=b#&type=c'),
-            [{'name': 'b'}, {'type': 'c'}])
-        self.assertEqual(
-            parse_test_path('t=n&a=aa&x=xx'),
-            [{'a': 'aa', 'name': 'n', 'type': 't', 'x': 'xx'}])
-        self.assertEqual(
-            parse_test_path('&a=aa&type=t&x=xx'),
-            [{'a': 'aa', 'type': 't', 'x': 'xx'}])
-        self.assertEqual(
-            parse_test_path('a=x%25%3D%23%26'),
-            [{'type': 'a', 'name': 'x%=#&'}])
-        self.assertEqual(
-            parse_test_path(''),
-            [])
+        self.assertEqual(parse_test_path('a=b#c=d'), [{'type': 'a', 'name': 'b'}, {'type': 'c', 'name': 'd'}])
+        self.assertEqual(parse_test_path('&name=b#&type=c'), [{'name': 'b'}, {'type': 'c'}])
+        self.assertEqual(parse_test_path('t=n&a=aa&x=xx'), [{'a': 'aa', 'name': 'n', 'type': 't', 'x': 'xx'}])
+        self.assertEqual(parse_test_path('&a=aa&type=t&x=xx'), [{'a': 'aa', 'type': 't', 'x': 'xx'}])
+        self.assertEqual(parse_test_path('a=x%25%3D%23%26'), [{'type': 'a', 'name': 'x%=#&'}])
+        self.assertEqual(parse_test_path(''), [])
         # See the comment on the parse_test_path.
         # self.assertEqual(
         #     parse_test_path('&'),
@@ -39,33 +26,17 @@ class TestPathEncodingTest(unittest.TestCase):
 
     def test_unparse(self):
         self.assertEqual(
-            unparse_test_path(
-                [{'type': 'a', 'name': 'b'}, {'type': 'c', 'name': 'd'}]),
-            'a=b#c=d')
+            unparse_test_path([{'type': 'a', 'name': 'b'}, {'type': 'c', 'name': 'd'}]), 'a=b#c=d')
         self.assertEqual(
-            unparse_test_path(
-                [{'type': None, 'name': 'b'}, {'type': 'c', 'name': None}]),
-            '&name=b#&type=c')
+            unparse_test_path([{'type': None, 'name': 'b'}, {'type': 'c', 'name': None}]), '&name=b#&type=c')
         self.assertEqual(
-            unparse_test_path(
-                [{'a': 'aa', 'name': 'n', 'type': 't', 'x': 'xx'}]),
-            't=n&a=aa&x=xx')
+            unparse_test_path([{'a': 'aa', 'name': 'n', 'type': 't', 'x': 'xx'}]), 't=n&a=aa&x=xx')
         self.assertEqual(
-            unparse_test_path(
-                [{'a': 'aa', 'type': 't', 'x': 'xx'}]),
-            '&a=aa&type=t&x=xx')
-        self.assertEqual(
-            unparse_test_path([{'a': 'x%=#&'}]),
-            '&a=x%25%3D%23%26')
-        self.assertEqual(
-            unparse_test_path([]),
-            '')
-        self.assertEqual(
-            unparse_test_path([{None: None}]),
-            '&')
-        self.assertEqual(
-            unparse_test_path([{None: None}, {None: None}]),
-            '&#&')
+            unparse_test_path([{'a': 'aa', 'type': 't', 'x': 'xx'}]), '&a=aa&type=t&x=xx')
+        self.assertEqual(unparse_test_path([{'a': 'x%=#&'}]), '&a=x%25%3D%23%26')
+        self.assertEqual(unparse_test_path([]), '')
+        self.assertEqual(unparse_test_path([{None: None}]), '&')
+        self.assertEqual(unparse_test_path([{None: None}, {None: None}]), '&#&')
 
 
 class TestFilePathNormalizer(unittest.TestCase):
@@ -105,7 +76,8 @@ class TestFilePathNormalizer(unittest.TestCase):
 
     @unittest.skipIf(
         sys.platform.startswith("win"),
-        "tempfile creates 8.3 filenames, and it's hard to deal with them. Practically, we don't see them often, so do not support them now until it's needed."
+        "tempfile creates 8.3 filenames, and it's hard to deal with them. "
+        "Practically, we don't see them often, so do not support them now until it's needed."
     )
     def test_inference_git(self):
         with tempfile.TemporaryDirectory() as tempdirname:
@@ -121,22 +93,20 @@ class TestFilePathNormalizer(unittest.TestCase):
 
     @unittest.skipIf(
         sys.platform.startswith("win"),
-        "tempfile creates 8.3 filenames, and it's hard to deal with them. Practically, we don't see them often, so do not support them now until it's needed. Also when this runs on Windows, GIT_AUTHOR_NAME etc. is ignored and fails."
+        "tempfile creates 8.3 filenames, and it's hard to deal with them. "
+        "Practically, we don't see them often, so do not support them now until it's needed. "
+        "Also when this runs on Windows, GIT_AUTHOR_NAME etc. is ignored and fails."
     )
     def test_inference_git_submodule(self):
         with tempfile.TemporaryDirectory() as tempdirname:
             temppath = pathlib.PurePath(tempdirname)
 
-            self._run_command(
-                ['git', 'init',
-                 str(temppath.joinpath("submod"))])
+            self._run_command(['git', 'init', str(temppath.joinpath("submod"))])
             self._run_command(
                 ['git', 'commit', '--allow-empty', '--message', 'test commit'],
                 cwd=str(temppath.joinpath("submod")))
 
-            self._run_command(
-                ['git', 'init',
-                 str(temppath.joinpath("gitrepo"))])
+            self._run_command(['git', 'init', str(temppath.joinpath("gitrepo"))])
             self._run_command(
                 ['git', '-c', 'protocol.file.allow=always', 'submodule', 'add', str(temppath.joinpath("submod")), 'submod'],
                 cwd=str(temppath.joinpath("gitrepo")))
@@ -163,9 +133,7 @@ class TestFilePathNormalizer(unittest.TestCase):
                     "GIT_COMMITTER_EMAIL": "user@example.com",
                 })
         except subprocess.CalledProcessError as e:
-            self.fail(
-                "Failed to execute a command: {}\nSTDOUT: {}\nSTDERR: {}\n".
-                format(e, e.stdout, e.stderr))
+            self.fail("Failed to execute a command: {}\nSTDOUT: {}\nSTDERR: {}\n".                format(e, e.stdout, e.stderr))
 
 
 if __name__ == '__main__':
